/*
   Copyright 2007-2009 Murali Krishnan

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */

package com.notuvy.gui;

import javax.swing.*;

import com.notuvy.util.DependentText;
import com.notuvy.util.ValueChangeHandler;
import com.notuvy.util.ValueHolder;
import com.notuvy.util.IconResource;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * A label with an icon that looks like an LED that displays state.
 *
 * @author  murali
 */
public class LEDLabel extends JLabel {

    //------------------------------------------------------------
    //- Class Variables

    public static final Icon RED = IconResource.get("/led_red.gif");
    public static final Icon GREEN = IconResource.get("/led_green.gif");


    //------------------------------------------------------------
    //- Class Functions


    //------------------------------------------------------------
    //- Instance Variables

    private final ValueHolder<Boolean> fController;


    //------------------------------------------------------------
    //- Constructors

    public LEDLabel(String pText, ValueHolder<Boolean> pController) {
        super (pText, RED, TRAILING);

        fController = pController;
        fController.addHandler(new IconChanger());
    }


    //------------------------------------------------------------
    //- Accessors


    //------------------------------------------------------------
    //- Settors


    //------------------------------------------------------------
    //- Private/Protected Utility Functions


    //------------------------------------------------------------
    //- Public Interface Functions

    public LEDLabel setDependentText(String pTextTrue, String pTextFalse) {
        fController.addHandler(new DependentText.Label(pTextTrue, pTextFalse, this));

        return this;
    }

    public LEDLabel setDependentToolTip(String pTextTrue, String pTextFalse) {
        fController.addHandler(new DependentText.ToolTip(pTextTrue, pTextFalse, this));

        return this;
    }


    //------------------------------------------------------------
    //- Class Interface Functions


    //------------------------------------------------------------
    //- Inner Classes

    private class IconChanger implements ValueChangeHandler<Boolean> {
        public void handleInitialValue(Boolean pValue) {
            handleValueChange(pValue);
        }

        public void handleValueChange(Boolean pValue) {
            setIcon(pValue ? GREEN : RED);
        }
    }


    //------------------------------------------------------------
    //- Main

    public static void main(String[] args) {
        try {
            final ValueHolder<Boolean> controller = new ValueHolder<Boolean>(true);
            LEDLabel label = new LEDLabel("", controller).setDependentText("On", "Off").setDependentToolTip("The connection has been established.", "Login required.");
            JButton button = new JButton("toggle");
            button.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent pActionEvent) {
                    controller.set(!controller.get());
                }
            });
            JPanel panel = new JPanel(new BorderLayout());
            panel.add(label, BorderLayout.WEST);
            panel.add(button, BorderLayout.EAST);
            JOptionPane.showMessageDialog(null, panel);
        } catch (Throwable thr) {
            thr.printStackTrace();
        }
    }


}
