package com.notuvy.util;


import javax.swing.*;

/**
 * Use one of two text values depending on a boolean flag.
 *
 * @author murali
 */
public abstract class DependentText implements ValueChangeHandler<Boolean> {

    //------------------------------------------------------------
    //- Class Variables



    //------------------------------------------------------------
    //- Class Functions


    //------------------------------------------------------------
    //- Instance Variables

    private final String fTextTrue;
    private final String fTextFalse;


    //------------------------------------------------------------
    //- Constructors

    public DependentText(String pTextTrue, String pTextFalse) {
        fTextTrue = pTextTrue;
        fTextFalse = pTextFalse;
    }


    //------------------------------------------------------------
    //- Gettors

    public String getTextTrue() {
        return fTextTrue;
    }

    public String getTextFalse() {
        return fTextFalse;
    }


    //------------------------------------------------------------
    //- Settors


    //------------------------------------------------------------
    //- Private/Protected Utility Functions


    //------------------------------------------------------------
    //- Public Interface Functions


    //------------------------------------------------------------
    //- Class Interface Functions

    public void handleInitialValue(Boolean pValue) {
        handleValueChange(pValue);
    }


    //------------------------------------------------------------
    //- Inner Classes

    static public class Label extends DependentText {
        private final JLabel fLabel;

        public Label(String pTextTrue, String pTextFalse, JLabel pLabel) {
            super(pTextTrue, pTextFalse);
            fLabel = pLabel;
        }

        public void handleValueChange(Boolean pValue) {
            fLabel.setText(pValue ? getTextTrue() : getTextFalse());
        }
    }

    static public class Menu extends DependentText {
        private final JMenuItem fMenuItem;

        public Menu(String pTextTrue, String pTextFalse, JMenuItem pLabel) {
            super(pTextTrue, pTextFalse);
            fMenuItem = pLabel;
        }

        public void handleValueChange(Boolean pValue) {
            fMenuItem.setText(pValue ? getTextTrue() : getTextFalse());
        }
    }

    static public class ToolTip extends DependentText {
        private final JComponent fComponent;

        public ToolTip(String pTextTrue, String pTextFalse, JComponent pLabel) {
            super(pTextTrue, pTextFalse);
            fComponent = pLabel;
        }

        public void handleValueChange(Boolean pValue) {
            fComponent.setToolTipText(pValue ? getTextTrue() : getTextFalse());
        }
    }


    //------------------------------------------------------------
    //- Main


}
