/*
   Copyright 2008-2009 Murali Krishnan

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */

package com.notuvy.util;

/**
 * Handle a change in value of an observable ValueHolder.
 *
 * @author  murali
 */
public interface ValueChangeHandler<T> {


    /**
     * Handle the initial value in the ValueHolder.
     * Note that this is necessary because when a handler is attached to a holder, there is no change
     * in value in the holder.  This method is used to have the handle initialize.
     *
     * @param pValue  The initial value.
     */
    void handleInitialValue(T pValue);

    /**
     * Handle the changed value in the ValueHolder.   This gets called each time a new value is set.
     *
     * @param pValue  The new value.
     */
    void handleValueChange(T pValue);

}
